@@ -122,6 +122,12 @@ class RealServerParameterError(Exception):
         super(RealServerParameterError, self).__init__(msg)
 
 
+class SubVsCannotCreateSubVs(Exception):
+    def __init__(self):
+        msg = "A sub virtual service cannot create a sub virtual service"
+        super(SubVsCannotCreateSubVs, self).__init__(msg)
+
+
 class MissingInfo(Exception):
     service = 'My service'
     param_name = 'parameter_name'
