@@ -1,6 +1,6 @@
 from nose.tools import (
     assert_equal, assert_raises, assert_true,
-    assert_is_none)
+    assert_is_none, assert_not_in)
 
 # handle py3 and py2 cases:
 try:
@@ -153,3 +153,29 @@ class Test_get_virtual_service:
                         protocol='tcp'
                         )
         assert_equal(res, sentinel.vs)
+
+
+class Test_show_interface:
+
+    def setup(self):
+        self.lm = LoadMaster("1.1.1.1", "bal", "2fourall")
+
+    def test_show_interface_when_id_is_nan(self):
+        with assert_raises(exceptions.ValidationError):
+            self.lm.show_interface("1")
+
+    def test_show_interface(self):
+        with patch.object(LoadMaster, "_get"):
+            with patch.object(client, "get_data") as get_data:
+                get_data.return_value = {"Interface": {"IPAddress": "10.154.190.110/16"}}
+                interface = self.lm.show_interface(0)
+                assert_equal(interface["IPAddress"], "10.154.190.110")
+                assert_equal(interface["cidr"], "16")
+
+    def test_show_interface_no_ip(self):
+        with patch.object(LoadMaster, "_get") as _get:
+            with patch.object(client, "get_data") as get_data:
+                get_data.return_value = {"Interface": {"IPAddress": None}}
+                interface = self.lm.show_interface(0)
+                assert_equal(interface["IPAddress"], None)
+                assert_not_in("cidr", interface)
